summaryrefslogtreecommitdiffstats
path: root/krusader/Dialogs
diff options
context:
space:
mode:
Diffstat (limited to 'krusader/Dialogs')
-rw-r--r--krusader/Dialogs/krdialogs.cpp6
-rw-r--r--krusader/Dialogs/krdialogs.h4
-rw-r--r--krusader/Dialogs/krkeydialog.cpp8
-rw-r--r--krusader/Dialogs/krkeydialog.h2
-rw-r--r--krusader/Dialogs/krmaskchoice.cpp8
-rw-r--r--krusader/Dialogs/krmaskchoice.h2
-rw-r--r--krusader/Dialogs/krspecialwidgets.cpp14
-rw-r--r--krusader/Dialogs/krspecialwidgets.h10
-rw-r--r--krusader/Dialogs/krspwidgets.cpp8
-rw-r--r--krusader/Dialogs/krspwidgets.h6
-rw-r--r--krusader/Dialogs/krsqueezedtextlabel.cpp4
-rw-r--r--krusader/Dialogs/krsqueezedtextlabel.h2
-rw-r--r--krusader/Dialogs/kurllistrequester.cpp2
-rw-r--r--krusader/Dialogs/kurllistrequester.h2
-rw-r--r--krusader/Dialogs/newftpgui.cpp6
-rw-r--r--krusader/Dialogs/newftpgui.h2
-rw-r--r--krusader/Dialogs/packguibase.cpp6
-rw-r--r--krusader/Dialogs/packguibase.h2
-rw-r--r--krusader/Dialogs/percentalsplitter.cpp4
-rw-r--r--krusader/Dialogs/percentalsplitter.h2
-rw-r--r--krusader/Dialogs/popularurls.cpp2
-rw-r--r--krusader/Dialogs/popularurls.h2
22 files changed, 52 insertions, 52 deletions
diff --git a/krusader/Dialogs/krdialogs.cpp b/krusader/Dialogs/krdialogs.cpp
index 56d60b2..037b354 100644
--- a/krusader/Dialogs/krdialogs.cpp
+++ b/krusader/Dialogs/krdialogs.cpp
@@ -130,9 +130,9 @@ KURL KChooseDir::getDir(TQString text,const KURL& url, const KURL& cwd, bool &pr
return u;
}
-KURLRequesterDlgForCopy::KURLRequesterDlgForCopy( const TQString& urlName, const TQString& _text, bool presAttrs, TQWidget *tqparent,
+KURLRequesterDlgForCopy::KURLRequesterDlgForCopy( const TQString& urlName, const TQString& _text, bool presAttrs, TQWidget *parent,
const char *name, bool modal, KURL baseURL )
- : KDialogBase( Plain, TQString(), Ok|Cancel|User1, Ok, tqparent, name, modal, true, KStdGuiItem::clear() ),
+ : KDialogBase( Plain, TQString(), Ok|Cancel|User1, Ok, parent, name, modal, true, KStdGuiItem::clear() ),
baseUrlCombo( 0 ), copyDirStructureCB( 0 ) {
TQVBoxLayout * topLayout = new TQVBoxLayout( plainPage(), 0, spacingHint() );
@@ -228,7 +228,7 @@ KURL KURLRequesterDlgForCopy::baseURL() const {
return vfs::fromPathOrURL( baseUrlCombo->currentText() );
}
-KRGetDate::KRGetDate(TQDate date, TQWidget *tqparent, const char *name) : KDialog(tqparent, name,true,WStyle_DialogBorder) {
+KRGetDate::KRGetDate(TQDate date, TQWidget *parent, const char *name) : KDialog(parent, name,true,WStyle_DialogBorder) {
dateWidget = new KDatePicker(this, date);
dateWidget->resize(dateWidget->tqsizeHint());
setMinimumSize(dateWidget->tqsizeHint());
diff --git a/krusader/Dialogs/krdialogs.h b/krusader/Dialogs/krdialogs.h
index ae33575..f250744 100644
--- a/krusader/Dialogs/krdialogs.h
+++ b/krusader/Dialogs/krdialogs.h
@@ -79,7 +79,7 @@ class KURLRequesterDlgForCopy : public KDialogBase {
TQ_OBJECT
public:
KURLRequesterDlgForCopy( const TQString& url, const TQString& text, bool presAttrs,
- TQWidget *tqparent, const char *name, bool modal=true, KURL baseURL = KURL() );
+ TQWidget *parent, const char *name, bool modal=true, KURL baseURL = KURL() );
KURLRequesterDlgForCopy();
KURL selectedURL() const;
@@ -103,7 +103,7 @@ class KRGetDate : public KDialog {
Q_OBJECT
TQ_OBJECT
public:
- KRGetDate(TQDate date=TQDate::tqcurrentDate(), TQWidget *tqparent = 0, const char *name = 0);
+ KRGetDate(TQDate date=TQDate::tqcurrentDate(), TQWidget *parent = 0, const char *name = 0);
TQDate getDate();
private slots:
diff --git a/krusader/Dialogs/krkeydialog.cpp b/krusader/Dialogs/krkeydialog.cpp
index e52e52b..0adaf7b 100644
--- a/krusader/Dialogs/krkeydialog.cpp
+++ b/krusader/Dialogs/krkeydialog.cpp
@@ -29,13 +29,13 @@
static const char* FILE_FILTER = I18N_NOOP("*.keymap|Krusader keymaps\n*|all files");
-KrKeyDialog::KrKeyDialog( TQWidget * tqparent ) : KKeyDialog( false /* allow letter shortcuts */, tqparent ) {
+KrKeyDialog::KrKeyDialog( TQWidget * parent ) : KKeyDialog( false /* allow letter shortcuts */, parent ) {
insert( krApp->actionCollection() );
// HACK This fetches the tqlayout of the buttonbox from KDialogBase, although it is not accessable with KDialogBase's API
// None the less it's quite save to use since this implementation hasn't changed since KDE-3.3 (I haven't looked at earlier
// versions since we don't support them) and now all work is done in KDE-4.
- TQWidget* buttonBox = TQT_TQWIDGET( actionButton(KDialogBase::Ok)->tqparent() );
+ TQWidget* buttonBox = TQT_TQWIDGET( actionButton(KDialogBase::Ok)->parent() );
TQBoxLayout* buttonBoxLayout = static_cast<TQBoxLayout*>( buttonBox->tqlayout() );
KPushButton* importButton = new KPushButton( i18n("Import shortcuts"), buttonBox );
@@ -67,7 +67,7 @@ void KrKeyDialog::slotImportShortcuts() {
KConfig conf( filename, true /*read only*/, false /*no KDEGlobal*/ );
if ( ! conf.hasGroup("Shortcuts") ) {
- int answer = KMessageBox::warningContinueCancel( this, //tqparent
+ int answer = KMessageBox::warningContinueCancel( this, //parent
i18n("This file does not seem to be a valid keymap.\n"
"It may be a keymap using a legacy format. The import can't be undone!"), //text
i18n("Try to import legacy format?"), //caption
@@ -118,7 +118,7 @@ void KrKeyDialog::importLegacyShortcuts( const TQString& file ) {
}
f.close();
- KMessageBox::information( this, // tqparent
+ KMessageBox::information( this, // parent
i18n("Please restart this dialog in order to see the changes"), // text
i18n("Legacy import completed") // caption
);
diff --git a/krusader/Dialogs/krkeydialog.h b/krusader/Dialogs/krkeydialog.h
index a07d9af..5bcdef8 100644
--- a/krusader/Dialogs/krkeydialog.h
+++ b/krusader/Dialogs/krkeydialog.h
@@ -23,7 +23,7 @@ class KrKeyDialog : protected KKeyDialog
Q_OBJECT
TQ_OBJECT
public:
- KrKeyDialog( TQWidget* tqparent = 0 );
+ KrKeyDialog( TQWidget* parent = 0 );
~KrKeyDialog();
private slots:
diff --git a/krusader/Dialogs/krmaskchoice.cpp b/krusader/Dialogs/krmaskchoice.cpp
index 4fb6d94..261366e 100644
--- a/krusader/Dialogs/krmaskchoice.cpp
+++ b/krusader/Dialogs/krmaskchoice.cpp
@@ -43,14 +43,14 @@
#include <tqlineedit.h>
/*
- * Constructs a KRMaskChoice which is a child of 'tqparent', with the
+ * Constructs a KRMaskChoice which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-KRMaskChoice::KRMaskChoice( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : TQDialog( tqparent, name, modal, fl )
+KRMaskChoice::KRMaskChoice( TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : TQDialog( parent, name, modal, fl )
{
if ( !name )
setName( "KRMaskChoice" );
@@ -94,7 +94,7 @@ KRMaskChoice::KRMaskChoice( TQWidget* tqparent, const char* name, bool modal, W
preSelections = new TQListBox( Layout6, "preSelections" );
preSelections->setVScrollBarMode( TQListBox::AlwaysOn );
- TQWhatsThis::add( preSelections, i18n( "A predefined selection is a file-tqmask which you use often.\nSome examples are: \"*.c, *.h\", \"*.c, *.o\", etc.\nYou can add these masks to the list by typing them and pressing the Add button.\nDelete removes a predefined selection and Clear removes all of them.\nNotice that the line in which you edit the tqmask has it's own history, you can scroll it, if needed." ) );
+ TQWhatsThis::add( preSelections, i18n( "A predefined selection is a file-mask which you use often.\nSome examples are: \"*.c, *.h\", \"*.c, *.o\", etc.\nYou can add these masks to the list by typing them and pressing the Add button.\nDelete removes a predefined selection and Clear removes all of them.\nNotice that the line in which you edit the mask has it's own history, you can scroll it, if needed." ) );
hbox_2->addWidget( preSelections );
vbox = new TQVBoxLayout;
diff --git a/krusader/Dialogs/krmaskchoice.h b/krusader/Dialogs/krmaskchoice.h
index c783c5c..0284734 100644
--- a/krusader/Dialogs/krmaskchoice.h
+++ b/krusader/Dialogs/krmaskchoice.h
@@ -47,7 +47,7 @@ class KRMaskChoice : public TQDialog
TQ_OBJECT
public:
- KRMaskChoice( TQWidget* tqparent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+ KRMaskChoice( TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
~KRMaskChoice();
TQComboBox* selection;
diff --git a/krusader/Dialogs/krspecialwidgets.cpp b/krusader/Dialogs/krspecialwidgets.cpp
index 0da9f91..63f2d74 100644
--- a/krusader/Dialogs/krspecialwidgets.cpp
+++ b/krusader/Dialogs/krspecialwidgets.cpp
@@ -64,8 +64,8 @@ TQColor KRPie::colors[ 12 ] = {TQt::red, TQt::blue, TQt::green, TQt::cyan, TQt::
/////////////// KRFSDisplay - Filesystem / Freespace Display /////////////////
//////////////////////////////////////////////////////////////////////////////
// This is the full constructor: use it for a mounted filesystem
-KRFSDisplay::KRFSDisplay( TQWidget *tqparent, TQString _alias, TQString _realName,
- KIO::filesize_t _total, KIO::filesize_t _free ) : TQWidget( tqparent ), totalSpace( _total ),
+KRFSDisplay::KRFSDisplay( TQWidget *parent, TQString _alias, TQString _realName,
+ KIO::filesize_t _total, KIO::filesize_t _free ) : TQWidget( parent ), totalSpace( _total ),
freeSpace( _free ), alias( _alias ), realName( _realName ), mounted( true ),
empty( false ), supermount( false ) {
resize( 150, 200 );
@@ -73,8 +73,8 @@ empty( false ), supermount( false ) {
}
// Use this one for an unmounted filesystem
-KRFSDisplay::KRFSDisplay( TQWidget *tqparent, TQString _alias, TQString _realName, bool sm ) :
- TQWidget( tqparent ), alias( _alias ), realName( _realName ), mounted( false ),
+KRFSDisplay::KRFSDisplay( TQWidget *parent, TQString _alias, TQString _realName, bool sm ) :
+ TQWidget( parent ), alias( _alias ), realName( _realName ), mounted( false ),
empty( false ), supermount( sm ) {
resize( 150, 200 );
show();
@@ -82,7 +82,7 @@ empty( false ), supermount( sm ) {
// This is used only when an empty widget needs to be displayed (for example:
// when filesystem statistics haven't been calculated yet)
-KRFSDisplay::KRFSDisplay( TQWidget *tqparent ) : TQWidget( tqparent ), empty( true ) {
+KRFSDisplay::KRFSDisplay( TQWidget *parent ) : TQWidget( parent ), empty( true ) {
resize( 150, 200 );
show();
}
@@ -146,7 +146,7 @@ void KRFSDisplay::paintEvent( TQPaintEvent * ) {
}
////////////////////////////////////////////////////////////////////////////////
-KRPie::KRPie( KIO::filesize_t _totalSize, TQWidget *tqparent ) : TQWidget( tqparent, 0 ), totalSize( _totalSize ) {
+KRPie::KRPie( KIO::filesize_t _totalSize, TQWidget *parent ) : TQWidget( parent, 0 ), totalSize( _totalSize ) {
slices.setAutoDelete( true ); // kill items when they are removed
slices.append( new KRPieSlice( 100, TQt::yellow, "DEFAULT" ) );
sizeLeft = totalSize;
@@ -204,7 +204,7 @@ void KRPie::addSlice( KIO::filesize_t size, TQString label ) {
////////////////////////////////////////////////////
/////////////////// KrQuickSearch /////////////////
////////////////////////////////////////////////////
-KrQuickSearch::KrQuickSearch( TQWidget *tqparent, const char * name ) : KLineEdit( tqparent, name ) {}
+KrQuickSearch::KrQuickSearch( TQWidget *parent, const char * name ) : KLineEdit( parent, name ) {}
void KrQuickSearch::myKeyPressEvent( TQKeyEvent *e ) {
switch ( e->key() ) {
diff --git a/krusader/Dialogs/krspecialwidgets.h b/krusader/Dialogs/krspecialwidgets.h
index 3952a89..66b6efb 100644
--- a/krusader/Dialogs/krspecialwidgets.h
+++ b/krusader/Dialogs/krspecialwidgets.h
@@ -46,7 +46,7 @@ class KRPie : public TQWidget {
Q_OBJECT
TQ_OBJECT
public:
- KRPie( KIO::filesize_t _totalSize, TQWidget *tqparent = 0 );
+ KRPie( KIO::filesize_t _totalSize, TQWidget *parent = 0 );
void addSlice( KIO::filesize_t size, TQString label );
protected:
@@ -63,12 +63,12 @@ class KRFSDisplay : public TQWidget {
TQ_OBJECT
public:
// this constructor is used for a mounted filesystem
- KRFSDisplay( TQWidget *tqparent, TQString _alias, TQString _realName,
+ KRFSDisplay( TQWidget *parent, TQString _alias, TQString _realName,
KIO::filesize_t _total, KIO::filesize_t _free );
// this one is for an unmounted/supermount file system
- KRFSDisplay( TQWidget *tqparent, TQString _alias, TQString _realName, bool sm = false );
+ KRFSDisplay( TQWidget *parent, TQString _alias, TQString _realName, bool sm = false );
// the last one is used inside MountMan(R), when no filesystem is selected
- KRFSDisplay( TQWidget *tqparent );
+ KRFSDisplay( TQWidget *parent );
inline void setTotalSpace( KIO::filesize_t t ) { totalSpace = t; }
inline void setFreeSpace( KIO::filesize_t t ) { freeSpace = t; }
inline void setAlias( TQString a ) { alias = a; }
@@ -106,7 +106,7 @@ class KrQuickSearch: public KLineEdit {
Q_OBJECT
TQ_OBJECT
public:
- KrQuickSearch(TQWidget *tqparent, const char * name = 0);
+ KrQuickSearch(TQWidget *parent, const char * name = 0);
void addText(const TQString &str) { setText(text()+str); }
void myKeyPressEvent(TQKeyEvent *e);
void myIMStartEvent(TQIMEvent* e) {
diff --git a/krusader/Dialogs/krspwidgets.cpp b/krusader/Dialogs/krspwidgets.cpp
index a4890b0..8fb19ba 100644
--- a/krusader/Dialogs/krspwidgets.cpp
+++ b/krusader/Dialogs/krspwidgets.cpp
@@ -229,11 +229,11 @@ void KRMaskChoiceSub::acceptFromList(TQListBoxItem *i) {
////////////////////////// QuickNavLineEdit ////////////////////
-QuickNavLineEdit::QuickNavLineEdit(const TQString &string, TQWidget *tqparent, const char *name):
- KLineEdit(string, tqparent, name) { init(); }
+QuickNavLineEdit::QuickNavLineEdit(const TQString &string, TQWidget *parent, const char *name):
+ KLineEdit(string, parent, name) { init(); }
-QuickNavLineEdit::QuickNavLineEdit(TQWidget *tqparent, const char *name):
- KLineEdit(tqparent, name) { init(); }
+QuickNavLineEdit::QuickNavLineEdit(TQWidget *parent, const char *name):
+ KLineEdit(parent, name) { init(); }
int QuickNavLineEdit::findCharFromPos(const TQString & str, const TQFontMetrics & metrics, int pos)
{
diff --git a/krusader/Dialogs/krspwidgets.h b/krusader/Dialogs/krspwidgets.h
index 69adc03..13098dc 100644
--- a/krusader/Dialogs/krspwidgets.h
+++ b/krusader/Dialogs/krspwidgets.h
@@ -48,7 +48,7 @@ class KRSpWidgets {
public:
KRSpWidgets();
- static KRQuery getMask( TQString caption, bool nameOnly=false ); // get file-tqmask for (un)selecting files
+ static KRQuery getMask( TQString caption, bool nameOnly=false ); // get file-mask for (un)selecting files
static KURL newFTP();
private:
@@ -89,8 +89,8 @@ protected:
class QuickNavLineEdit: public KLineEdit {
public:
- QuickNavLineEdit(const TQString &string, TQWidget *tqparent, const char *name=0);
- QuickNavLineEdit(TQWidget *tqparent=0, const char *name=0);
+ QuickNavLineEdit(const TQString &string, TQWidget *parent, const char *name=0);
+ QuickNavLineEdit(TQWidget *parent=0, const char *name=0);
virtual ~QuickNavLineEdit() {}
static int findCharFromPos(const TQString &, const TQFontMetrics &, int pos);
protected:
diff --git a/krusader/Dialogs/krsqueezedtextlabel.cpp b/krusader/Dialogs/krsqueezedtextlabel.cpp
index 6ec6b61..7a5ef8d 100644
--- a/krusader/Dialogs/krsqueezedtextlabel.cpp
+++ b/krusader/Dialogs/krsqueezedtextlabel.cpp
@@ -3,8 +3,8 @@
#include <kurldrag.h>
#include <tqtooltip.h>
-KrSqueezedTextLabel::KrSqueezedTextLabel(TQWidget *tqparent, const char *name):
- KSqueezedTextLabel(tqparent, name), acceptDrops( false ), _index(-1), _length(-1) {
+KrSqueezedTextLabel::KrSqueezedTextLabel(TQWidget *parent, const char *name):
+ KSqueezedTextLabel(parent, name), acceptDrops( false ), _index(-1), _length(-1) {
}
diff --git a/krusader/Dialogs/krsqueezedtextlabel.h b/krusader/Dialogs/krsqueezedtextlabel.h
index f75309f..0fd1b3a 100644
--- a/krusader/Dialogs/krsqueezedtextlabel.h
+++ b/krusader/Dialogs/krsqueezedtextlabel.h
@@ -18,7 +18,7 @@ class KrSqueezedTextLabel : public KSqueezedTextLabel {
Q_OBJECT
TQ_OBJECT
public:
- KrSqueezedTextLabel(TQWidget *tqparent = 0, const char *name = 0);
+ KrSqueezedTextLabel(TQWidget *parent = 0, const char *name = 0);
~KrSqueezedTextLabel();
void enableDrops( bool flag );
diff --git a/krusader/Dialogs/kurllistrequester.cpp b/krusader/Dialogs/kurllistrequester.cpp
index 32f1cda..7e3cf1c 100644
--- a/krusader/Dialogs/kurllistrequester.cpp
+++ b/krusader/Dialogs/kurllistrequester.cpp
@@ -41,7 +41,7 @@
#define DELETE_ITEM_ID 100
-KURLListRequester::KURLListRequester( TQWidget *tqparent, const char * name ) : TQWidget( tqparent, name )
+KURLListRequester::KURLListRequester( TQWidget *parent, const char * name ) : TQWidget( parent, name )
{
KIconLoader *iconLoader = new KIconLoader();
TQPixmap imageAdd = iconLoader->loadIcon( "1downarrow", KIcon::Panel, 16 );
diff --git a/krusader/Dialogs/kurllistrequester.h b/krusader/Dialogs/kurllistrequester.h
index 60891b1..2dd8e67 100644
--- a/krusader/Dialogs/kurllistrequester.h
+++ b/krusader/Dialogs/kurllistrequester.h
@@ -44,7 +44,7 @@ class KURLListRequester : public TQWidget
TQ_OBJECT
public:
- KURLListRequester( TQWidget *tqparent = 0, const char * name = 0 );
+ KURLListRequester( TQWidget *parent = 0, const char * name = 0 );
KURL::List urlList();
void setUrlList( KURL::List );
diff --git a/krusader/Dialogs/newftpgui.h b/krusader/Dialogs/newftpgui.h
index 6fc5621..6e1f84b 100644
--- a/krusader/Dialogs/newftpgui.h
+++ b/krusader/Dialogs/newftpgui.h
@@ -25,7 +25,7 @@ class newFTPGUI : public TQDialog {
Q_OBJECT
TQ_OBJECT
public:
- newFTPGUI( TQWidget* tqparent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+ newFTPGUI( TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
~newFTPGUI();
TQLabel* TextLabel1;
diff --git a/krusader/Dialogs/packguibase.h b/krusader/Dialogs/packguibase.h
index 5d0a829..abad2ab 100644
--- a/krusader/Dialogs/packguibase.h
+++ b/krusader/Dialogs/packguibase.h
@@ -54,7 +54,7 @@ class PackGUIBase : public TQDialog
TQ_OBJECT
public:
- PackGUIBase( TQWidget* tqparent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+ PackGUIBase( TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
~PackGUIBase();
TQLabel* TextLabel3;
diff --git a/krusader/Dialogs/percentalsplitter.cpp b/krusader/Dialogs/percentalsplitter.cpp
index d73b61d..27c2267 100644
--- a/krusader/Dialogs/percentalsplitter.cpp
+++ b/krusader/Dialogs/percentalsplitter.cpp
@@ -35,7 +35,7 @@
class PercentalSplitterToolTip : public TQToolTip {
public:
- PercentalSplitterToolTip( TQWidget * tqparent ) : TQToolTip( tqparent ) {
+ PercentalSplitterToolTip( TQWidget * parent ) : TQToolTip( parent ) {
}
virtual ~PercentalSplitterToolTip() {
@@ -63,7 +63,7 @@ public:
}
};
-PercentalSplitter::PercentalSplitter( TQWidget * tqparent, const char * name ) : TQSplitter( tqparent, name ), label( 0 ), opaqueOldPos( -1 ) {
+PercentalSplitter::PercentalSplitter( TQWidget * parent, const char * name ) : TQSplitter( parent, name ), label( 0 ), opaqueOldPos( -1 ) {
toolTip = new PercentalSplitterToolTip( this );
}
diff --git a/krusader/Dialogs/percentalsplitter.h b/krusader/Dialogs/percentalsplitter.h
index b35d3aa..c1d4166 100644
--- a/krusader/Dialogs/percentalsplitter.h
+++ b/krusader/Dialogs/percentalsplitter.h
@@ -41,7 +41,7 @@ class PercentalSplitter : public TQSplitter {
TQ_OBJECT
public:
- PercentalSplitter( TQWidget * tqparent = 0, const char * name = 0 );
+ PercentalSplitter( TQWidget * parent = 0, const char * name = 0 );
virtual ~PercentalSplitter();
TQString toolTipString( int p = -1 );
diff --git a/krusader/Dialogs/popularurls.cpp b/krusader/Dialogs/popularurls.cpp
index a6c4759..a6ae087 100644
--- a/krusader/Dialogs/popularurls.cpp
+++ b/krusader/Dialogs/popularurls.cpp
@@ -16,7 +16,7 @@
#define INCREASE 2
#define DECREASE 1
-PopularUrls::PopularUrls(TQObject *tqparent, const char *name) : TQObject(tqparent, name),
+PopularUrls::PopularUrls(TQObject *parent, const char *name) : TQObject(parent, name),
head(0), tail(0), count(0) {
dlg = new PopularUrlsDlg();
}
diff --git a/krusader/Dialogs/popularurls.h b/krusader/Dialogs/popularurls.h
index 98dab8a..e41d573 100644
--- a/krusader/Dialogs/popularurls.h
+++ b/krusader/Dialogs/popularurls.h
@@ -30,7 +30,7 @@ class PopularUrls : public TQObject {
Q_OBJECT
TQ_OBJECT
public:
- PopularUrls(TQObject *tqparent = 0, const char *name = 0);
+ PopularUrls(TQObject *parent = 0, const char *name = 0);
~PopularUrls();
void save();
void load();
diff --git a/krusader/Dialogs/newftpgui.cpp b/krusader/Dialogs/newftpgui.cpp
index 56e63b1..d121e03 100644
--- a/krusader/Dialogs/newftpgui.cpp
+++ b/krusader/Dialogs/newftpgui.cpp
@@ -28,7 +28,7 @@
/*
* Constructs a newFTPGUI which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
@@ -37,8 +37,8 @@
#define SIZE_MINIMUM TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0 )
-newFTPGUI::newFTPGUI( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : TQDialog( tqparent, name, modal, fl ){
+newFTPGUI::newFTPGUI( TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : TQDialog( parent, name, modal, fl ){
TQVBoxLayout * tqlayout = new TQVBoxLayout( this, 11, 6, "newFTPGUI_layout" );
tqlayout->setAutoAdd(true);
@@ -28,7 +28,7 @@
/*
- * Constructs a newFTPGUI which is a child of 'tqparent', with the
+ * Constructs a newFTPGUI which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*
diff --git a/krusader/Dialogs/packguibase.cpp b/krusader/Dialogs/packguibase.cpp
index 71c507f..34e888b 100644
--- a/krusader/Dialogs/packguibase.cpp
+++ b/krusader/Dialogs/packguibase.cpp
@@ -53,14 +53,14 @@
#include "../krusader.h"
/*
* Constructs a PackGUIBase which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-PackGUIBase::PackGUIBase( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : TQDialog( tqparent, name, modal, fl ), expanded( false )
+PackGUIBase::PackGUIBase( TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : TQDialog( parent, name, modal, fl ), expanded( false )
{
if ( !name )
setName( "PackGUIBase" );
@@ -53,14 +53,14 @@
#include "../krusader.h"
/*
- * Constructs a PackGUIBase which is a child of 'tqparent', with the
+ * Constructs a PackGUIBase which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*